How to...
----------

.. toctree::
   :caption: How to...
   :maxdepth: 1

   tutorial/10_Extract_curves_into_striplogs.ipynb
   tutorial/11_Parse_a_description_into_components.ipynb
   tutorial/12_Calculate_sand_proportion.ipynb
   tutorial/13_Work_with_binary_logs.ipynb
   tutorial/14_Merge_overlapping_striplogs.ipynb
   tutorial/15_Model_sequences_with_Markov_chains.ipynb
   tutorial/16_Block_logs.ipynb